@@ -1,9 +1,11 @@
 #include "zm_crypt.h"
 
 #include "zm_logger.h"
+#include "zm_utils.h"
 #include "BCrypt.hpp"
 #include <algorithm>
 #include <cstring>
+#include <random>
 
 #if HAVE_LIBJWT
 #include <jwt.h>
@@ -11,16 +13,9 @@
 #include <jwt-cpp/jwt.h>
 #endif
 
-#if HAVE_LIBCRYPTO
-#include <openssl/sha.h>
-#elif HAVE_GNUTLS_GNUTLS_H
-#include <gnutls/gnutls.h>
-#include <gnutls/crypto.h>
-#endif
-
 // returns username if valid, "" if not
 #if HAVE_LIBJWT
-std::pair <std::string, unsigned int> verifyToken(std::string jwt_token_str, std::string key) {
+std::pair <std::string, unsigned int> verifyToken(const std::string &jwt_token_str, const std::string &key) {
   std::string username = "";
   unsigned int token_issued_at = 0;
   int err = 0;
@@ -38,15 +33,15 @@ std::pair <std::string, unsigned int> verifyToken(std::string jwt_token_str, std
     Error("Error setting Algorithm for JWT decode");
     return std::make_pair("", 0);
   }
-  
+
   err = jwt_decode(&jwt, jwt_token_str.c_str(),
-      reinterpret_cast<const unsigned char *>(key.c_str()), key.length());
+                   reinterpret_cast<const unsigned char *>(key.c_str()), key.length());
   if (err) {
     jwt_free(jwt);
     Error("Could not decode JWT");
     return std::make_pair("", 0);
   }
-  
+
   const char *c_type = jwt_get_grant(jwt, (const char*)"type");
   if (!c_type) {
     jwt_free(jwt);
@@ -67,29 +62,29 @@ std::pair <std::string, unsigned int> verifyToken(std::string jwt_token_str, std
 
   username = std::string(c_username);
   Debug(1, "Got %s as user claim from token", username.c_str());
-  
+
   token_issued_at = (unsigned int)jwt_get_grant_int(jwt, "iat");
   if (errno == ENOENT) {
     jwt_free(jwt);
     Error("IAT not found in claim. This should not happen");
     return std::make_pair("", 0);
   }
-  
+
   Debug(1, "Got IAT token=%u", token_issued_at);
   jwt_free(jwt);
   return std::make_pair(username, token_issued_at);
 }
 #else // HAVE_LIBJWT
-std::pair <std::string, unsigned int> verifyToken(std::string jwt_token_str, std::string key) {
+std::pair <std::string, unsigned int> verifyToken(const std::string &jwt_token_str, const std::string &key) {
   std::string username = "";
   unsigned int token_issued_at = 0;
   try {
     // is it decodable?
     auto decoded = jwt::decode(jwt_token_str);
     auto verifier = jwt::verify()
-                        .allow_algorithm(jwt::algorithm::hs256{ key })
-                        .with_issuer("ZoneMinder");
-  
+                    .allow_algorithm(jwt::algorithm::hs256{ key })
+                    .with_issuer("ZoneMinder");
+
     // signature verified?
     verifier.verify(decoded);
 
@@ -115,7 +110,7 @@ std::pair <std::string, unsigned int> verifyToken(std::string jwt_token_str, std
     }
 
     if (decoded.has_payload_claim("iat")) {
-      token_issued_at = (unsigned int) (decoded.get_payload_claim("iat").as_int());
+      token_issued_at = (unsigned int) (decoded.get_payload_claim("iat").as_integer());
       Debug(1, "Got IAT token=%u", token_issued_at);
     } else {
       Error("IAT not found in claim. This should not happen");
@@ -125,8 +120,7 @@ std::pair <std::string, unsigned int> verifyToken(std::string jwt_token_str, std
   catch (const std::exception &e) {
     Error("Unable to verify token: %s", e.what());
     return std::make_pair("", 0);
-  }
-  catch (...) {
+  } catch (...) {
     Error("unknown exception");
     return std::make_pair("", 0);
   }
@@ -135,63 +129,31 @@ std::pair <std::string, unsigned int> verifyToken(std::string jwt_token_str, std
 #endif // HAVE_LIBJWT
 
 bool verifyPassword(const char *username, const char *input_password, const char *db_password_hash) {
+  using namespace zm::crypto;
+
   bool password_correct = false;
   if ( strlen(db_password_hash) < 4 ) {
-    // actually, shoud be more, but this is min. for next code
+    // actually, should be more, but this is min. for next code
     Error("DB Password is too short or invalid to check");
     return false;
   }
   if ( db_password_hash[0] == '*' ) {
     // MYSQL PASSWORD
-    Debug(1, "%s is using an MD5 encoded password", username);
-    
-    #ifndef SHA_DIGEST_LENGTH
-      #define SHA_DIGEST_LENGTH 20
-    #endif
-    
-#if HAVE_LIBCRYPTO
-    unsigned char digest_interim[SHA_DIGEST_LENGTH];
-    unsigned char digest_final[SHA_DIGEST_LENGTH];
-    SHA_CTX ctx1, ctx2;
-    
-    //get first iteration
-    SHA1_Init(&ctx1);
-    SHA1_Update(&ctx1, input_password, strlen(input_password));
-    SHA1_Final(digest_interim, &ctx1);
+    Debug(1, "%s is using an SHA1 encoded password", username);
 
-    //2nd iteration
-    SHA1_Init(&ctx2);
-    SHA1_Update(&ctx2, digest_interim,SHA_DIGEST_LENGTH);
-    SHA1_Final(digest_final, &ctx2);
-#elif HAVE_GNUTLS_GNUTLS_H
-    unsigned char digest_interim[SHA_DIGEST_LENGTH];
-    unsigned char digest_final[SHA_DIGEST_LENGTH];
-    //get first iteration
-    gnutls_hash_fast(GNUTLS_DIG_SHA1, input_password, strlen(input_password), digest_interim);
-    //2nd iteration
-    gnutls_hash_fast(GNUTLS_DIG_SHA1, digest_interim, SHA_DIGEST_LENGTH, digest_final);
-#else
-    Error("Authentication Error. ZoneMinder not built with GnuTLS or Openssl");
-    return false;
-#endif
+    SHA1::Digest digest = SHA1::GetDigestOf(SHA1::GetDigestOf(input_password));
+    std::string hex_digest = '*' + StringToUpper(ByteArrayToHexString(digest));
 
-    char final_hash[SHA_DIGEST_LENGTH * 2 +2];
-    final_hash[0] = '*';
-    //convert to hex
-    for ( int i = 0; i < SHA_DIGEST_LENGTH; i++ )
-      sprintf(&final_hash[i*2]+1, "%02X", (unsigned int)digest_final[i]);
-    final_hash[SHA_DIGEST_LENGTH *2 + 1] = 0;
-
-    Debug(1, "Computed password_hash:%s, stored password_hash:%s", final_hash, db_password_hash);
-    password_correct = (strcmp(db_password_hash, final_hash)==0);
+    Debug(1, "Computed password_hash: %s, stored password_hash: %s", hex_digest.c_str(), db_password_hash);
+    password_correct = (strcmp(db_password_hash, hex_digest.c_str()) == 0);
   } else if (
-      (db_password_hash[0] == '$')
-      &&
-      (db_password_hash[1] == '2')
-      &&
-      (db_password_hash[3] == '$')
-      ) {
-    // BCRYPT 
+    (db_password_hash[0] == '$')
+    &&
+    (db_password_hash[1] == '2')
+    &&
+    (db_password_hash[3] == '$')
+  ) {
+    // BCRYPT
     Debug(1, "%s is using a bcrypt encoded password", username);
     BCrypt bcrypt;
     password_correct = bcrypt.validatePassword(std::string(input_password), std::string(db_password_hash));
@@ -201,7 +163,23 @@ bool verifyPassword(const char *username, const char *input_password, const char
   } else {
     Warning("%s is using a plain text (not recommended) or scheme not understood", username);
     password_correct = (strcmp(input_password, db_password_hash) == 0);
-  } 
-  
+  }
+
   return password_correct;
 }
+
+std::string generateKey(const int length) {
+
+  const std::string lookup = "0123456789ABCDEF";
+
+  std::random_device rnd;
+  std::mt19937 rng(rnd());
+  std::uniform_int_distribution<> genDigit(0,15);
+  std::string keyBuffer (length, '0');
+  for ( int i = 0; i < length; i++ ) {
+    keyBuffer[i] = lookup[genDigit(rng)];
+  }
+  return keyBuffer;
+
+
+}
