@@ -138,7 +138,6 @@ MYSQL_RES *zmDbFetch(const std::string &query) {
   }
 
 
-  Debug(3, "Doing Fetch %s", query.c_str());
   int rc = mysql_query(&dbconn, query.c_str());
   if (rc) {
     std::string reason = mysql_error(&dbconn); // store for later because it will get clobbered by second attempt
@@ -172,7 +171,7 @@ MYSQL_RES *zmDbRow::fetch(const std::string &query) {
   if (!result_set) return result_set;
 
   int n_rows = mysql_num_rows(result_set);
-  if (n_rows > 1) {
+  if (n_rows != 1) {
     Error("Bogus number of lines return from query, %d returned for query %s.", n_rows, query.c_str());
     mysql_free_result(result_set);
     result_set = nullptr;
@@ -326,8 +325,8 @@ void zmDbQueue::push(std::string &&sql) {
     std::unique_lock<std::mutex> lock(mMutex);
     if (mTerminate) return;
     mQueue.push(std::move(sql));
-    mCondition.notify_all();
   }
+  mCondition.notify_all();
 }
 
 std::string zmDbEscapeString(const std::string& to_escape) {
