@@ -65,7 +65,7 @@ int FFmpeg_Input::Open(const char *filepath) {
 
 
   for (unsigned int i = 0; i < input_format_context->nb_streams; i += 1) {
-    av_seek_frame(input_format_context, i, 0, AVSEEK_FLAG_FRAME);
+    //av_seek_frame(input_format_context, i, 0, AVSEEK_FLAG_FRAME);
 
     if (is_video_stream(input_format_context->streams[i])) {
       zm_dump_stream_format(input_format_context, i, 0, 0);
@@ -98,10 +98,13 @@ int FFmpeg_Input::Open(const char *filepath) {
 
       streams[i].context = avcodec_alloc_context3(streams[i].codec);
       avcodec_parameters_to_context(streams[i].context, input_format_context->streams[i]->codecpar);
+
       if (setup_hwaccel(streams[i].context,
-            chosen_codec_data, hw_device_ctx, "", input_format_context->streams[i]->codecpar->width,
+            chosen_codec_data, hw_device_ctx, "",
+            input_format_context->streams[i]->codecpar->width,
             input_format_context->streams[i]->codecpar->height
             )) {
+        Warning("Failed to setup hw_accel");
         continue;
       }
 
@@ -111,13 +114,16 @@ int FFmpeg_Input::Open(const char *filepath) {
       if (error < 0) {
         Error("Could not open input codec (error '%s')",
             av_make_error_string(error).c_str());
-        avcodec_free_context(&streams[i].context);
+
+        avcodec_free_context(&(streams[i].context));
         streams[i].context = nullptr;
         continue;
       }
+      break;
     } // end foreach codec_data
  
     if (!streams[i].context) {
+      Debug(1, "Failed with known codecs, trying harder");
       if ((streams[i].codec = avcodec_find_decoder(input_format_context->streams[i]->codecpar->codec_id))) {
         Debug(1, "Using codec (%s) for stream %d", streams[i].codec->name, i);
         streams[i].context = avcodec_alloc_context3(streams[i].codec);
@@ -141,7 +147,7 @@ int FFmpeg_Input::Open(const char *filepath) {
       return error;
     }
     zm_dump_codec(streams[i].context);
-    if (!(streams[i].context->time_base.num && streams[i].context->time_base.den)) {
+    if (0 and !(streams[i].context->time_base.num && streams[i].context->time_base.den)) {
       Debug(1, "Setting to default time base");
       streams[i].context->time_base.num = 1;
       streams[i].context->time_base.den = 90000;
@@ -188,9 +194,35 @@ AVFrame *FFmpeg_Input::get_frame(int stream_id) {
     return nullptr;
   }
 
+  AVCodecContext *context = streams[stream_id].context;
 
   while (!frameComplete) {
-    int ret = av_read_frame(input_format_context, packet.get());
+
+    frame = av_frame_ptr{av_frame_alloc()};
+    if (!frame) {
+      Error("Unable to allocate frame.");
+      return nullptr;
+    }
+
+    // Since technically sending a packet can result in multiple frames (or buffered_frames) try receive_frame first.
+    int ret = avcodec_receive_frame(context, frame.get());
+    Debug(1, "Ret from receive_frame ret: %d %s", ret, av_make_error_string(ret).c_str());
+    if (ret == AVERROR(EAGAIN)) {
+      // Perfectly normal
+    } else if (ret < 0) {
+      Error("Ret from receive_frame ret: %d %s", ret, av_make_error_string(ret).c_str());
+      return nullptr;
+    } else {
+      frameComplete = true;
+      if (is_video_stream(input_format_context->streams[packet->stream_index])) {
+        zm_dump_video_frame(frame.get(), "resulting video frame");
+      } else {
+        zm_dump_frame(frame.get(), "resulting frame");
+      }
+      break;
+    }
+
+    ret = av_read_frame(input_format_context, packet.get());
     if (ret < 0) {
       if (
         // Check if EOF.
@@ -207,40 +239,21 @@ AVFrame *FFmpeg_Input::get_frame(int stream_id) {
     }
     ZM_DUMP_STREAM_PACKET(input_format_context->streams[packet->stream_index], packet, "Received packet");
 
-    av_packet_guard pkt_guard{packet};
+    //av_packet_guard pkt_guard{packet};
 
     if ((stream_id >= 0) && (packet->stream_index != stream_id)) {
       Debug(4, "Packet is not for our stream (%d)", packet->stream_index );
       continue;
     }
 
-    AVCodecContext *context = streams[packet->stream_index].context;
-
-    frame = av_frame_ptr{zm_av_frame_alloc()};
-    if (!frame) {
-      Error("Unable to allocate frame.");
-      return nullptr;
-    }
-    ret = zm_send_packet_receive_frame(context, frame.get(), *packet);
-    if ( ret < 0 ) {
-      Error("Unable to decode frame at frame %d: %d %s, continuing",
-            streams[packet->stream_index].frame_count, ret, av_make_error_string(ret).c_str());
-      frame = nullptr;
+    ret = avcodec_send_packet(context, packet.get());
+    if (ret == AVERROR(EAGAIN)) {
+      Debug(2, "Unable to send packet %d %s", ret, av_make_error_string(ret).c_str());
       continue;
-    } else {
-      if (is_video_stream(input_format_context->streams[packet->stream_index])) {
-        zm_dump_video_frame(frame.get(), "resulting video frame");
-      } else {
-        zm_dump_frame(frame.get(), "resulting frame");
-      }
     }
-
-    frameComplete = true;
-
-    if (is_video_stream(input_format_context->streams[packet->stream_index])) {
-      zm_dump_video_frame(frame.get(), "resulting video frame");
-    } else {
-      zm_dump_frame(frame.get(), "resulting frame");
+    if (ret < 0) {
+      Error("Unable to send packet %d %s", ret, av_make_error_string(ret).c_str());
+      return nullptr;
     }
   } // end while !frameComplete
   return frame.get();
@@ -262,7 +275,7 @@ AVFrame *FFmpeg_Input::get_frame(int stream_id, double at) {
     ret = av_seek_frame(input_format_context, stream_id, seek_target, AVSEEK_FLAG_FRAME);
     if (ret < 0) {
       Error("Unable to seek in stream");
-      //return nullptr;
+      return nullptr;
     }
     // Have to grab a frame to update our current frame to know where we are
     get_frame(stream_id);
