@@ -92,7 +92,7 @@ AVFrame *FFmpeg_Output::get_frame( int stream_id ) {
     return nullptr;
   }
 
-  frame = av_frame_ptr{zm_av_frame_alloc()};
+  frame = av_frame_ptr{av_frame_alloc()};
   if (!frame) {
     Error("Unable to allocate frame.");
     return nullptr;
