@@ -8,7 +8,7 @@ $data = array();
 //
 
 if (!canView('Events'))
-  $message = 'Insufficient permissions for user '.$user['Username'].'<br/>';
+  $message = 'Insufficient permissions for user '.$user->Username().'<br/>';
 
 if (empty($_REQUEST['task'])) {
   $message = 'Must specify a task<br/>';
@@ -30,8 +30,23 @@ if ($message) {
 
 require_once('includes/Filter.php');
 $filter = isset($_REQUEST['filter']) ? ZM\Filter::parse($_REQUEST['filter']) : new ZM\Filter();
-if ($user['MonitorIds']) {
-  $filter = $filter->addTerm(array('cnj'=>'and', 'attr'=>'MonitorId', 'op'=>'IN', 'val'=>$user['MonitorIds']));
+if (count( $user->unviewableMonitorIds())) {
+  $filter = $filter->addTerm(array('cnj'=>'and', 'attr'=>'MonitorId', 'op'=>'IN', 'val'=>$user->viewableMonitorIds()));
+  // $filter = $filter->addTerm(array('cnj'=>'and', 'attr'=>'MonitorId', 'op'=>'IN', 'val'=>'5'));
+}
+// TODO: Why is $user->viewableMonitorIds() returning $user->unviewableMonitorIds()
+// Error('$user->viewableMonitorIds(): '.print_r($user->viewableMonitorIds()));
+if (!empty($_REQUEST['StartDateTime'])) {
+  $filter->addTerm(array('cnj'=>'and', 'attr'=>'StartDateTime', 'op'=> '>=', 'val'=>$_REQUEST['StartDateTime']));
+}
+if (!empty($_REQUEST['EndDateTime'])) {
+  $filter->addTerm(array('cnj'=>'and', 'attr'=>'EndDateTime', 'op'=> '<=', 'val'=>$_REQUEST['EndDateTime']));
+}
+if (!empty($_REQUEST['MonitorId'])) {
+  $filter->addTerm(array('cnj'=>'and', 'attr'=>'MonitorId', 'op'=> '=', 'val'=>$_REQUEST['MonitorId']));
+}
+if (!empty($_REQUEST['Tag'])) {
+  $filter->addTerm(array('cnj'=>'and', 'attr'=>'Tag', 'op'=>'=', 'val'=>''));
 }
 
 // Search contains a user entered string to search on
@@ -57,18 +72,11 @@ if (isset($_REQUEST['order'])) {
 $sort = $filter->sort_field();
 if (isset($_REQUEST['sort'])) {
   $sort = $_REQUEST['sort'];
-  if ($sort == 'EndDateTime') {
-    if ($order == 'ASC') {
-      $sort = 'EndDateTime IS NULL, EndDateTime';
-    } else {
-      $sort = 'EndDateTime IS NOT NULL, EndDateTime';
-    }
-  }
 }
 
 // Offset specifies the starting row to return, used for pagination
 $offset = 0;
-if (isset($_REQUEST['offset'])) {
+if (isset($_REQUEST['offset']) and ($_REQUEST['offset'] != 'NaN')) {
   if ((!is_int($_REQUEST['offset']) and !ctype_digit($_REQUEST['offset']))) {
     ZM\Error('Invalid value for offset: ' . $_REQUEST['offset']);
   } else {
@@ -79,7 +87,7 @@ if (isset($_REQUEST['offset'])) {
 // Limit specifies the number of rows to return
 // Set the default to 0 for events view, to prevent an issue with ALL pagination
 $limit = 0;
-if (isset($_REQUEST['limit'])) {
+if (isset($_REQUEST['limit']) and ($_REQUEST['limit'] != 'NaN')) {
   if ((!is_int($_REQUEST['limit']) and !ctype_digit($_REQUEST['limit']))) {
     ZM\Error('Invalid value for limit: ' . $_REQUEST['limit']);
   } else {
@@ -98,20 +106,21 @@ switch ($task) {
   case 'unarchive' :
 		# The idea is that anyone can archive, but only people with Event Edit permission can unarchive..
 		if (!canEdit('Events'))  {
-			ajaxError('Insufficient permissions for user '.$user['Username']);
+			ajaxError('Insufficient permissions for user '.$user->Username());
 			return;
 		}
     foreach ($eids as $eid) archiveRequest($task, $eid);
     break;
   case 'delete' :
 		if (!canEdit('Events'))  {
-			ajaxError('Insufficient permissions for user '.$user['Username']);
+			ajaxError('Insufficient permissions for user '.$user->Username());
 			return;
 		}
     foreach ($eids as $eid) {
       $message = deleteRequest($eid);
-      if (count($message)) {
-        $data[] = $message;
+      if ($message) {
+        if (empty($data['message'])) $data['message'] = [];
+        $data['message'][] = $message;
       }
     }
     break;
@@ -137,19 +146,18 @@ function archiveRequest($task, $eid) {
 }
 
 function deleteRequest($eid) {
-  $message = array();
   $event = new ZM\Event($eid);
-  if ( !$event->Id() ) {
-    $message[] = array($eid=>'Event not found.');
+  if (!$event->Id()) {
+    return 'Event '.$eid.' not found.';
   } else if ( $event->Archived() ) {
-    $message[] = array($eid=>'Event is archived, cannot delete it.');
+    return 'Event '.$eid.' is archived, cannot delete it.';
   } else if (!$event->canEdit()) {
-    $message[] = array($eid=>'You do not have permission to delete event '.$event->Id());
+    return 'You do not have permission to delete event '.$event->Id();
   } else {
     $event->delete();
   }
   
-  return $message;
+  return '';
 }
 
 function queryRequest($filter, $search, $advsearch, $sort, $offset, $order, $limit) {
@@ -174,14 +182,22 @@ function queryRequest($filter, $search, $advsearch, $sort, $offset, $order, $lim
   $columns = array('Id', 'MonitorId', 'StorageId', 'Name', 'Cause', 'StartDateTime', 'EndDateTime', 'Length', 'Frames', 'AlarmFrames', 'TotScore', 'AvgScore', 'MaxScore', 'Archived', 'Emailed', 'Notes', 'DiskSpace');
 
   // The names of columns shown in the event view that are NOT dB columns in the database
-  $col_alt = array('Monitor', 'MonitorName', 'Storage');
+  $col_alt = array('Monitor', 'Tags', 'Storage');
 
   if ( $sort != '' ) {
     if (!in_array($sort, array_merge($columns, $col_alt))) {
       ZM\Error('Invalid sort field: ' . $sort);
       $sort = '';
-    } else if ( $sort == 'Monitor' or $sort == 'MonitorName' ) {
+    } else if ( $sort == 'Tags' ) {
+       $sort = 'T.Name';
+    } else if ( $sort == 'Monitor' ) {
       $sort = 'M.Name';
+    } else if ($sort == 'EndDateTime') {
+      if ($order == 'ASC') {
+        $sort = 'E.EndDateTime IS NULL, E.EndDateTime';
+      } else {
+        $sort = 'E.EndDateTime IS NOT NULL, E.EndDateTime';
+      }
     } else {
       $sort = 'E.'.$sort;
     }
@@ -189,12 +205,29 @@ function queryRequest($filter, $search, $advsearch, $sort, $offset, $order, $lim
 
   $values = array();
   $likes = array();
+  // ZM\Error($filter->sql());
   $where = $filter->sql()?' WHERE ('.$filter->sql().')' : '';
+  $has_post_sql_conditions = count($filter->post_sql_conditions());
 
-  $col_str = 'E.*, M.Name AS Monitor';
-  $sql = 'SELECT ' .$col_str. ' FROM `Events` AS E INNER JOIN Monitors AS M ON E.MonitorId = M.Id'.$where.($sort?' ORDER BY '.$sort.' '.$order:'');
-  if ($filter->limit() and !count($filter->post_sql_conditions())) {
-    $sql .= ' LIMIT '.$filter->limit();
+
+  $col_str = '
+  E.*, 
+  UNIX_TIMESTAMP(E.StartDateTime) AS StartTimeSecs, 
+  CASE WHEN E.EndDateTime IS NULL THEN (SELECT NOW()) ELSE E.EndDateTime END AS EndDateTime, 
+  CASE WHEN E.EndDateTime IS NULL THEN (SELECT UNIX_TIMESTAMP(NOW())) ELSE UNIX_TIMESTAMP(EndDateTime) END AS EndTimeSecs, 
+  M.Name AS Monitor,
+  GROUP_CONCAT(T.Name SEPARATOR ", ") AS Tags';
+
+  $sql = 'SELECT '.$col_str.' FROM `Events` AS E 
+  INNER JOIN Monitors AS M ON E.MonitorId = M.Id 
+  LEFT JOIN Events_Tags AS ET ON E.Id = ET.EventId 
+  LEFT JOIN Tags AS T ON T.Id = ET.TagId 
+  '.$where.' 
+  GROUP BY E.Id, Monitor
+  '.($sort?' ORDER BY '.$sort.' '.$order:'');
+
+  if ((int)($filter->limit()) and !$has_post_sql_conditions) {
+    $sql .= ' LIMIT '.(int)($filter->limit());
   }
 
   $storage_areas = ZM\Storage::find();
@@ -213,12 +246,14 @@ function queryRequest($filter, $search, $advsearch, $sort, $offset, $order, $lim
     return;
   }
   while ($row = dbFetchNext($query)) {
-    $event = new ZM\Event($row);
-    $event->remove_from_cache();
-    if (!$filter->test_post_sql_conditions($event)) {
-      continue;
+    if ($has_post_sql_conditions) {
+      $event = new ZM\Event($row);
+      $event->remove_from_cache();
+      if (!$filter->test_post_sql_conditions($event)) {
+        continue;
+      }
     }
-    $event_ids[] = $event->Id();
+    $event_ids[] = $row['Id'];
     $unfiltered_rows[] = $row;
   } # end foreach row
 
@@ -251,7 +286,7 @@ function queryRequest($filter, $search, $advsearch, $sort, $offset, $order, $lim
       $search = '%' .$search. '%';
       $terms = array();
       foreach ($columns as $col) {
-        $terms[] = array('cnj'=>'or', 'attr'=>$col, 'op'=>'LIKE', 'val'=>$search);
+        $terms[] = array('cnj'=>'or', 'attr'=>$col, 'op'=>'LIKE', 'val'=>strtolower($search), 'collate'=>'utf8mb4_general_ci');
       }
       $terms[0]['obr'] = 1;
       $terms[0]['cnj'] = 'and';
@@ -259,21 +294,31 @@ function queryRequest($filter, $search, $advsearch, $sort, $offset, $order, $lim
       $search_filter = $search_filter->addTerms($terms, array('obr'=>1, 'cbr'=>1, 'op'=>'OR'));
     } # end if search
 
-    $sql = 'SELECT ' .$col_str. ' FROM `Events` AS E INNER JOIN Monitors AS M ON E.MonitorId = M.Id WHERE '.$search_filter->sql().' ORDER BY ' .$sort. ' ' .$order;
+    $sql = 'SELECT '.$col_str.' FROM `Events` AS E 
+    INNER JOIN Monitors AS M ON E.MonitorId = M.Id 
+    LEFT JOIN Events_Tags AS ET ON E.Id = ET.EventId 
+    LEFT JOIN Tags AS T ON T.Id = ET.TagId 
+    WHERE '.$search_filter->sql().' 
+    GROUP BY E.Id 
+    ORDER BY ' .$sort. ' ' .$order;
+
     $filtered_rows = dbFetchAll($sql);
     ZM\Debug('Have ' . count($filtered_rows) . ' events matching search filter: '.$sql);
   } else {
     $filtered_rows = $unfiltered_rows;
   } # end if search_filter->terms() > 1
 
-  if ($limit) {
-    ZM\Debug("Filtering rows due to limit " . count($filtered_rows)." offset: $offset limit: $limit");
+  if ($limit and ($limit < count($filtered_rows))) {
+    ZM\Debug("Filtering rows due to limit rows: " . count($filtered_rows)." offset: $offset limit: $limit");
     $filtered_rows = array_slice($filtered_rows, $offset, $limit);
   }
 
   $returned_rows = array();
   foreach ($filtered_rows as $row) {
     $event = new ZM\Event($row);
+    $event->remove_from_cache();
+    if (!$event->canView()) continue;
+    if ($event->Monitor()->Deleted()) continue;
 
     $scale = intval(5*100*ZM_WEB_LIST_THUMB_WIDTH / $event->Width());
     $imgSrc = $event->getThumbnailSrc(array(), '&amp;');
@@ -282,19 +327,21 @@ function queryRequest($filter, $search, $advsearch, $sort, $offset, $order, $lim
 
     // Modify the row data as needed
     $row['imgHtml'] = '<img id="thumbnail' .$event->Id(). '" src="' .$imgSrc. '" alt="Event '.$event->Id().'" width="' .validInt($event->ThumbnailWidth()). '" height="' .validInt($event->ThumbnailHeight()).'" stream_src="' .$streamSrc. '" still_src="' .$imgSrc. '" loading="lazy" />';
+    $row['imgWidth'] = validInt($event->ThumbnailWidth());
+    $row['imgHeight'] = validInt($event->ThumbnailHeight());
+
     $row['Name'] = validHtmlStr($row['Name']);
     $row['Archived'] = $row['Archived'] ? translate('Yes') : translate('No');
     $row['Emailed'] = $row['Emailed'] ? translate('Yes') : translate('No');
     $row['Cause'] = validHtmlStr($row['Cause']);
-    $row['StartDateTime'] = $dateTimeFormatter->format(strtotime($row['StartDateTime']));
-    $row['EndDateTime'] = $row['EndDateTime'] ? $dateTimeFormatter->format(strtotime($row['EndDateTime'])) : null;
+    $row['Tags'] = validHtmlStr($row['Tags']);
     $row['Storage'] = ( $row['StorageId'] and isset($StorageById[$row['StorageId']]) ) ? $StorageById[$row['StorageId']]->Name() : 'Default';
-    $row['Notes'] = nl2br(htmlspecialchars($row['Notes']));
+    $row['Notes'] = $row['Notes'] ? nl2br(htmlspecialchars($row['Notes'])) : '';
     $row['DiskSpace'] = human_filesize($event->DiskSpace());
     $returned_rows[] = $row;
   } # end foreach row matching search
 
-  $data['rows'] = $returned_rows;
+  $data['rows'] = &$returned_rows;
 
   # totalNotFiltered must equal total, except when either search bar has been used
   $data['totalNotFiltered'] = count($unfiltered_rows);
@@ -303,7 +350,7 @@ function queryRequest($filter, $search, $advsearch, $sort, $offset, $order, $lim
   } else {
     $data['total'] = $data['totalNotFiltered'];
   }
-
+  ZM\Debug("Done");
   return $data;
 }
 ?>
