@@ -202,8 +202,7 @@ class Monitor extends ZM_Object {
     if (!isset($RTSP2WebStreamOptions)) {
       $RTSP2WebStreamOptions = array(
         'Primary' => translate('Primary'),
-        'Secondary' => translate('Secondary'),
-        'Restream' => translate('Restream')
+        'Secondary' => translate('Secondary')
       );
     }
     return $RTSP2WebStreamOptions;
@@ -225,10 +224,6 @@ class Monitor extends ZM_Object {
     'RecordingSource' => 'Primary',
     'AnalysisSource' => 'Primary',
     'AnalysisImage' => 'FullColour',
-    'ObjectDetection' => 'None',
-    'ObjectDetectionModel' => '',
-    'ObjectDetectionObjectThreshold' => '0.4',
-    'ObjectDetectionNMSThreshold' => '0.25',
     'Enabled'   => array('type'=>'boolean','default'=>1),
     'Decoding'  => 'Always',
     'RTSP2WebEnabled'   => array('type'=>'integer','default'=>0),
@@ -281,10 +276,8 @@ class Monitor extends ZM_Object {
     'SaveJPEGs' =>  0,
     'VideoWriter' =>  '2',
     'OutputCodecName' =>  'auto',
-    'OutputContainer' => null,
     'Encoder'     =>  'auto',
-    'EncoderHWAccelName'  =>  null,
-    'EncoderHWAccelDevice'  =>  null,
+    'OutputContainer' => null,
     'EncoderParameters' => '',
     'WallClockTimestamps' => array('type'=>'boolean', 'default'=>0),
     'RecordAudio' =>  array('type'=>'boolean', 'default'=>0),
@@ -349,6 +342,7 @@ class Monitor extends ZM_Object {
     'MQTT_Enabled'   => array('type'=>'boolean','default'=>0),
     'MQTT_Subscriptions'  =>  '',
     'StartupDelay' => 0,
+    'initial_scale' => array('default'=>100, 'do_not_update'=>1),
   );
   private $status_fields = array(
     'Status'  =>  null,
@@ -500,7 +494,7 @@ class Monitor extends ZM_Object {
 
   public function __call($fn, array $args) {
     if (count($args)) {
-      if (is_array($this->defaults[$fn]) and $this->defaults[$fn]['type'] == 'set') {
+      if (is_array($this->defaults[$fn]) and isset($this->defaults[$fn]['type']) and $this->defaults[$fn]['type'] == 'set') {
         $this->{$fn} = is_array($args[0]) ? implode(',', $args[0]) : $args[0];
       } else {
         $this->{$fn} = $args[0];
@@ -549,7 +543,7 @@ class Monitor extends ZM_Object {
   }
 
   public function getStreamSrc($args, $querySep='&amp;') {
-    $streamSrc = $this->Server()->UrlToZMS(ZM_MIN_STREAMING_PORT ? ZM_MIN_STREAMING_PORT+(int)($this->{'Id'}/5) : null);
+    $streamSrc = $this->Server()->UrlToZMS(ZM_MIN_STREAMING_PORT ? ZM_MIN_STREAMING_PORT+$this->{'Id'} : null);
 
     $args['monitor'] = $this->{'Id'};
 
@@ -879,6 +873,7 @@ class Monitor extends ZM_Object {
     }
     return $this->Groups;
   }
+
   function connKey($new='') {
     if ($new)
       $this->connKey = $new;
