@@ -66,7 +66,7 @@ if ( $action == 'delete' ) {
     if ( ($config['Type'] == 'boolean') and empty($_REQUEST['newConfig'][$config['Name']]) ) {
       $newValue = 0;
     } else if (isset($_REQUEST['newConfig'][$config['Name']])) {
-      $newValue = preg_replace('/\r\n/', '\n', $_REQUEST['newConfig'][$config['Name']]);
+      $newValue = preg_replace("/\r\n/", "\n", $_REQUEST['newConfig'][$config['Name']]);
     }
 
     if (isset($newValue) && ($newValue != $config['Value'])) {
