@@ -9,7 +9,6 @@ function MonitorStream(monitorData) {
   this.connKey = monitorData.connKey;
   this.url = monitorData.url;
   this.url_to_zms = monitorData.url_to_zms;
-  this.url_to_stream = monitorData.url_to_stream;
   this.width = monitorData.width;
   this.height = monitorData.height;
   this.RTSP2WebEnabled = monitorData.RTSP2WebEnabled;
@@ -34,7 +33,7 @@ function MonitorStream(monitorData) {
   this.janusEnabled = monitorData.janusEnabled;
   this.janusPin = monitorData.janus_pin;
   this.server_id = monitorData.server_id;
-  this.scale = 100;
+  this.scale = monitorData.scale ? parseInt(monitorData.scale) : 100;
   this.status = {capturefps: 0, analysisfps: 0}; // json object with alarmstatus, fps etc
   this.lastAlarmState = STATE_IDLE;
   this.statusCmdTimer = null; // timer for requests using ajax to get monitor status
@@ -196,7 +195,7 @@ function MonitorStream(monitorData) {
       console.log('No stream in setScale');
       return;
     }
-    console.log("setScale", stream);
+    console.log("setScale", stream, newscale, width, height, param);
 
     // Scale the frame
     const monitor_frame = $j('#monitor'+this.id);
@@ -278,6 +277,7 @@ function MonitorStream(monitorData) {
       streamQuality = param.streamQuality;
       newscale += parseInt(newscale/100*streamQuality);
     }
+    this.scale = newscale;
     this.setStreamScale(newscale, streamQuality);
   }; // setScale
 
@@ -331,16 +331,17 @@ function MonitorStream(monitorData) {
   };
 
   /*
-  * streamChannel = 0 || Primary; 1 || Secondary.; 2 || Restream
+  * streamChannel = 0 || Primary; 1 || Secondary.
   */
   this.start = function(streamChannel = 'default') {
     if (streamChannel === null || streamChannel === '' || currentView == 'montage') streamChannel = 'default';
-    if (!['default', 0, 1, 2].includes(streamChannel)) {
+    if (!['default', 0, 1].includes(streamChannel)) {
       streamChannel = (streamChannel.toLowerCase() == 'primary') ? 0 : 1;
     }
-    console.log('streamChannel', streamChannel);
     this.streamListenerBind = streamListener.bind(null, this);
 
+    console.log('start', this.Go2RTCEnabled, this.player);
+
     $j('#volumeControls').hide();
 
     if (this.Go2RTCEnabled && ((!this.player) || (-1 !== this.player.indexOf('go2rtc')))) {
@@ -355,7 +356,6 @@ function MonitorStream(monitorData) {
         const Go2RTCModUrl = url;
         const webrtcUrl = Go2RTCModUrl;
         this.currentChannelStream = (streamChannel == 'default') ? ((this.RTSP2WebStream == 'Secondary') ? 1 : 0) : streamChannel;
-        console.log(this.currentChannelStream);
         webrtcUrl.protocol = (url.protocol=='https:') ? 'wss:' : 'ws';
         webrtcUrl.pathname += "/ws";
         //webrtcUrl.search = 'src='+this.id;
@@ -507,20 +507,22 @@ function MonitorStream(monitorData) {
     if (stream.getAttribute('loading') == 'lazy') {
       stream.setAttribute('loading', 'eager');
     }
-    let src = this.url_to_zms.replace(/mode=single/i, 'mode=jpeg');
-    if (-1 == src.search('auth')) {
-      src += '&'+auth_relay;
-    } else {
-      src = src.replace(/auth=\w+/i, 'auth='+auth_hash);
-    }
-    if (-1 == src.search('connkey')) {
-      src += '&connkey='+this.connKey;
-    }
     stream.onerror = this.img_onerror.bind(this);
     stream.onload = this.img_onload.bind(this);
-
-    stream.src = src;
-    this.streamCommand(CMD_PLAY);
+    if (-1 != stream.src.indexOf('mode=paused')) {
+      this.streamCommand(CMD_PLAY);
+    } else {
+      let src = this.url_to_zms.replace(/mode=single/i, 'mode=jpeg');
+      if (-1 == src.search('auth')) {
+        src += '&'+auth_relay;
+      } else {
+        src = src.replace(/auth=\w+/i, 'auth='+auth_hash);
+      }
+      if (-1 == src.search('connkey')) {
+        src += '&connkey='+this.connKey;
+      }
+      stream.src = src;
+    } // end if paused or not
     this.started = true;
     this.streamListenerBind();
     this.activePlayer = 'zms';
@@ -698,6 +700,7 @@ function MonitorStream(monitorData) {
   };
 
   this.play = function() {
+    console.log('play');
     if ((this.activePlayer) && (-1 !== this.activePlayer.indexOf('go2rtc'))) {
       this.element.play(); // go2rtc player will handle mute
       this.statusCmdTimer = setInterval(this.statusCmdQuery.bind(this), statusRefreshTimeout);
@@ -1082,9 +1085,10 @@ function MonitorStream(monitorData) {
             $j('#level'+this.id).addClass('hidden');
             if (this.onplay) this.onplay();
           } // end if paused or delayed
+
           if ((this.status.scale !== undefined) && (this.status.scale !== undefined) && (this.status.scale != this.scale)) {
             if (this.status.scale != 0) {
-              console.log("Stream not scaled on "+this.id+", re-applying", this.scale, this.status.scale);
+              console.log("Stream not scaled, re-applying want:", this.scale, "current:", this.status.scale);
               this.streamCommand({command: CMD_SCALE, scale: this.scale});
             }
           }
