@@ -346,7 +346,7 @@ $SLANG = array(
     'HasWhiteSpeed'        => 'Has White Bal. Speed',
     'HasZoomSpeed'         => 'Has Zoom Speed',
     'High'                 => 'Alta',
-    'HighBW'               => 'Alta&nbsp;B/W',
+    'Highband'               => 'Alta&nbsp;B/W',
     'Home'                 => 'Home',
     'Hostname'             => 'Hostname',               // Added - 2018-08-30
     'Hour'                 => 'Hora',
@@ -384,7 +384,7 @@ $SLANG = array(
     'Logout'               => 'Salir',
     'Logs'                 => 'Logs',                   // Added - 2011-06-17
     'Low'                  => 'Baja',
-    'LowBW'                => 'Baja&nbsp;B/W',
+    'Lowband'                => 'Baja&nbsp;B/W',
     'Main'                 => 'Main',
     'Man'                  => 'Man',
     'Manual'               => 'Manual',
@@ -415,7 +415,7 @@ $SLANG = array(
     'MaxZoomStep'          => 'Max Zoom Step',
     'MaximumFPS'           => 'Maximos FPS',
     'Medium'               => 'Media',
-    'MediumBW'             => 'Media&nbsp;B/W',
+    'Medband'             => 'Media&nbsp;B/W',
     'Message'              => 'Message',                // Added - 2011-06-16
     'MinAlarmAreaLtMax'    => 'Minimum alarm area should be less than maximum',
     'MinAlarmAreaUnset'    => 'You must specify the minimum alarm pixel count',
