@@ -395,7 +395,7 @@ $SLANG = array(
     'HasWhiteSpeed'         => 'Tiene velocidad de balance de blancos',
     'HasZoomSpeed'          => 'Tiene velocidad de zoom',
     'High'                  => 'Alto',
-    'HighBW'                => 'Alto&nbsp;B/B',
+    'Highband'                => 'Alto&nbsp;B/B',
     'Home'                  => 'Inicio',
     'Hostname'             => 'Hostname',               // Added - 2018-08-30
     'Hour'                  => 'Hora',
@@ -433,7 +433,7 @@ $SLANG = array(
     'Logout'                => 'Cerrar sesión',
     'Logs'                  => 'Registros',
     'Low'                   => 'Bajo',
-    'LowBW'                 => 'Bajo&nbsp;B/B',
+    'Lowband'                 => 'Bajo&nbsp;B/B',
     'Main'                  => 'Principal',
     'Man'                   => 'Man',
     'Manual'                => 'Manual',
@@ -464,7 +464,7 @@ $SLANG = array(
     'MaxZoomStep'           => 'Grado de zoom máximo',
     'MaximumFPS'            => 'MPS Máximos',
     'Medium'                => 'Medio',
-    'MediumBW'              => 'Medio&nbsp;B/B',
+    'Medband'              => 'Medio&nbsp;B/B',
     'Message'               => 'Mensaje',
     'MinAlarmAreaLtMax'     => 'El área mínima de alarma debe ser menor que la máxima',
     'MinAlarmAreaUnset'     => 'Debe especificar la mínima cantidad de píxeles de alarma',
