@@ -18,13 +18,6 @@
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
 
-$Go2RTCTypes = array(
-  'WebRTC' => 'WebRTC',
-  'MSE' => 'MSE',
-  #'RTSP' => 'RTSP',
-  'HLS' => 'HLS',
-  'MJPEG' => 'MJPEG'
-);
 $RTSP2WebTypes = array(
   'HLS' => 'HLS',
   'MSE' => 'MSE',
@@ -157,4 +150,21 @@ switch ( $_COOKIE['zmBandwidth'] ) {
     }
 }
 
+$available_views = [
+  'console'=>translate('Console'),
+  'filter'=>translate('Filters'),
+  'groups' =>translate('Groups'),
+  'log'=>translate('Log'),
+  'watch'=>translate('Cycle'),
+  'montage'=>translate('Montage'),
+  'montagereview'=>translate('Montage Review'),
+  'options'=>translate('Options'),
+  'reports'=>translate('Reports'),
+  'report_event_audit'=>translate('Audit Events Report')
+];
+if (defined('ZM_OPT_USE_GEOLOCATION') and ZM_OPT_USE_GEOLOCATION)
+  $available_views['map'] = translate('Map');
+if (defined('ZM_FEATURES_SNAPSHOTS') and ZM_FEATURES_SNAPSHOTS)
+  $available_views['snapshots'] = translate('Snapshots');
+
 ?>
