@@ -32,6 +32,7 @@ function xhtmlHeadersStart($file, $title) {
   global $view;
   global $cspNonce;
   global $basename;
+  global $user;
 
   # This idea is that we always include the classic css files, 
   # and then any different skin only needs to contain things that are different.
@@ -452,7 +453,7 @@ function output_script($files, $cache_bust=true, $must_exist=true) {
 }
 
 function output_script_if_exists($files, $cache_bust=true) {
-  return output_script($files, $cash_bust, false);
+  return output_script($files, $cache_bust, false);
 }
 
 function output_cache_busted_stylesheet_links($files) {
@@ -955,8 +956,8 @@ function getNavBrandHTML() {
 function getConsoleHTML($forLeftBar = false) {
   global $user;
   $result = '';
-
-  if (count($user->viewableMonitorIds()) or !ZM\Monitor::find_one()) {
+  
+  if ((count($user->viewableMonitorIds()) or !ZM\Monitor::find_one()) and $user->canViewView('console')) {
     if ($forLeftBar) {
       $result .= buildMenuItem(
         $viewItemName = 'console',
@@ -977,8 +978,14 @@ function getConsoleHTML($forLeftBar = false) {
 
 // Returns the html representing the Options menu item
 function getOptionsHTML($forLeftBar = false) {
-  global $zmMenu;
+  global $user;
   $result = '';
+  
+  if (!(canView('System') and $user->canViewView('options'))) {
+    return $result;
+  }
+
+  global $zmMenu;
 
   // Sorting order of the "Options" submenu items. If a submenu item is in the DB but is not here, it will be automatically added to the end of the list.
   $zmMenu::buildSubMenuOptions($categoryDisplayOrder = [
@@ -1009,20 +1016,19 @@ function getOptionsHTML($forLeftBar = false) {
     'version'
   ]);
 
-  if ( canView('System') ) {
-    if ($forLeftBar) {
-      global $view;
+  if ($forLeftBar) {
+    global $view;
 
-      $view_ = 'options';
-      //$tab = isset($_REQUEST['tab']) ? validHtmlStr($_REQUEST['tab']) : 'system';
-      $tab = isset($_REQUEST['tab']) ? validHtmlStr($_REQUEST['tab']) : '';
+    $view_ = 'options';
+    //$tab = isset($_REQUEST['tab']) ? validHtmlStr($_REQUEST['tab']) : 'system';
+    $tab = isset($_REQUEST['tab']) ? validHtmlStr($_REQUEST['tab']) : '';
 
-      $subMenuOptions = '
+    $subMenuOptions = '
       <div class="sub-menu-list">
         <ul>
       ';
-      foreach ($zmMenu::$submenuOptionsItems as $name=>$value) {
-        $subMenuOptions .= '
+    foreach ($zmMenu::$submenuOptionsItems as $name=>$value) {
+      $subMenuOptions .= '
           <li class="menu-item '.$name.' '.($tab == $name ? ' active' : '').'">
             <a href="?view='.$view_.'&amp;tab='.$name.'">
               <span class="menu-title">'.$value.'</span>
@@ -1045,16 +1051,16 @@ function getOptionsHTML($forLeftBar = false) {
     } else {
       $result .= '<li id="getOptionsHTML" class="nav-item"><a class="nav-link" href="?view=options">'.translate('Options').'</a></li>'.PHP_EOL;
     }
-  }
 
   return $result;
 }
 
 // Returns the html representing the Log menu item
 function getLogHTML($forLeftBar = false) {
+  global $user;
   $result = '';
   
-  if ( canView('System') ) {
+  if ( canView('System') and $user->canViewView('log')) {
     if ( ZM\logToDatabase() > ZM\Logger::NOLOG ) {
       $logstate = logState();
       $class = ($logstate == 'ok') ? 'text-success' : ($logstate == 'alert' ? 'text-warning' : (($logstate == 'alarm' ? 'text-danger' : '')));
@@ -1079,9 +1085,10 @@ function getLogHTML($forLeftBar = false) {
 
 // Returns the html representing the log icon
 function getLogIconHTML() {
+  global $user;
   $result = '';
-
-  if ( canView('System') ) {
+  
+  if ( canView('System') and $user->canViewView('log')) {
     if ( ZM\logToDatabase() > ZM\Logger::NOLOG ) { 
       $logstate = logState();
       $class = ($logstate == 'ok') ? 'text-success' : ($logstate == 'alert' ? 'text-warning' : (($logstate == 'alarm' ? 'text-danger' : '')));
@@ -1119,8 +1126,10 @@ function getDevicesHTML($forLeftBar = false) {
 
 // Returns the html representing the Groups menu item
 function getGroupsHTML($view, $forLeftBar = false) {
+  global $user;
   $result = '';
-  if ( !canView('Groups') ) return $result;
+  if (!(canView('Groups') and $user->canViewView('groups')) )
+    return $result;
 
   $class = $view == 'groups' ? ' selected' : '';
   if ($forLeftBar) {
@@ -1142,8 +1151,9 @@ function getGroupsHTML($view, $forLeftBar = false) {
 
 // Returns the html representing the Filter menu item
 function getFilterHTML($view, $forLeftBar = false) {
+  global $user;
   $result = '';
-  if ( !canView('Events') ) return $result;
+  if (!(canView('Events') and $user->canViewView('filter'))) return $result;
   
   $class = $view == 'filter' ? ' selected' : '';
   if ($forLeftBar) {
@@ -1165,10 +1175,11 @@ function getFilterHTML($view, $forLeftBar = false) {
 
 // Returns the html representing the Cycle menu item
 function getCycleHTML($view, $forLeftBar = false) {
+  global $user;
   $result = '';
   
-  if ( canView('Stream') ) {
-    $class = $view == 'cycle' ? ' selected' : '';
+  if (canView('Stream') and $user->canViewView('watch')) {
+    $class = $view == 'watch' ? ' selected' : '';
     if ($forLeftBar) {
       $result .= buildMenuItem(
         $viewItemName = 'watch',
@@ -1192,8 +1203,8 @@ function getCycleHTML($view, $forLeftBar = false) {
 function getMontageHTML($view, $forLeftBar = false) {
   global $user;
   $result = '';
-
-  if (canView('Stream') and count($user->viewableMonitorIds())) {
+  
+  if (canView('Stream') and $user->canViewView('montage') and count($user->viewableMonitorIds())) {
     $class = $view == 'montage' ? ' selected' : '';
     if ($forLeftBar) {
       $result .= buildMenuItem(
@@ -1215,9 +1226,10 @@ function getMontageHTML($view, $forLeftBar = false) {
 
 // Returns the html representing the MontageReview menu item
 function getMontageReviewHTML($view, $forLeftBar = false) {
+  global $user;
   $result = '';
   
-  if ( canView('Events') ) {
+  if (canView('Events') and $user->canViewView('montagereview')) {
     if ( isset($_REQUEST['filter']['Query']['terms']['attr']) ) {
       $terms = $_REQUEST['filter']['Query']['terms'];
       $count = 0;
@@ -1254,9 +1266,10 @@ function getMontageReviewHTML($view, $forLeftBar = false) {
 
 // Returns the html representing the Montage menu item
 function getSnapshotsHTML($view, $forLeftBar = false) {
+  global $user;
   $result = '';
-
-  if (defined('ZM_FEATURES_SNAPSHOTS') and ZM_FEATURES_SNAPSHOTS and canView('Snapshots')) {
+  
+  if (defined('ZM_FEATURES_SNAPSHOTS') and ZM_FEATURES_SNAPSHOTS and canView('Snapshots') and $user->canViewView('snapshots')) {
     $class = $view == 'snapshots' ? ' selected' : '';
     if ($forLeftBar) {
       $result .= buildMenuItem(
@@ -1302,9 +1315,10 @@ function getEventsHTML($view, $forLeftBar = false) {
 }
 
 function getReportsHTML($view, $forLeftBar = false) {
+  global $user;
   $result = '';
-
-  if (canView('Events')) {
+  
+  if (canView('Events') and $user->canViewView('reports')) {
     $class = ($view == 'reports' or $view == 'report') ? ' selected' : '';
     if ($forLeftBar) {
       $result .= buildMenuItem(
@@ -1326,9 +1340,10 @@ function getReportsHTML($view, $forLeftBar = false) {
 
 // Returns the html representing the Audit Events Report menu item
 function getRprtEvntAuditHTML($view, $forLeftBar = false) {
+  global $user;
   $result = '';
-
-  if ( canView('Events') ) {
+  
+  if (canView('Events') and $user->canViewView('report_event_audit')) {
     $class = $view == 'report_event_audit' ? ' selected' : '';
     if ($forLeftBar) {
       $result .= buildMenuItem(
@@ -1350,9 +1365,10 @@ function getRprtEvntAuditHTML($view, $forLeftBar = false) {
 
 // Returns the html representing the Audit Events Report menu item
 function getMapHTML($view, $forLeftBar = false) {
+  global $user;
   $result = '';
 
-  if (defined('ZM_OPT_USE_GEOLOCATION') and ZM_OPT_USE_GEOLOCATION) {
+  if (defined('ZM_OPT_USE_GEOLOCATION') and ZM_OPT_USE_GEOLOCATION and $user->canViewView('map')) {
     $class = $view == 'map' ? ' selected' : '';
     if ($forLeftBar) {
       $result .= buildMenuItem(
@@ -1437,7 +1453,7 @@ function getAccountCircleHTML($skin, $user=null, $forLeftBar = false) {
   if ( ZM_OPT_USE_AUTH and $user ) {
     $result .= '<li id="getAccountCircleHTML" class="navbar-text navbar-nav mr-2">'.PHP_EOL;
     $result .= makeLink('#', '<i class="material-icons">account_circle</i> '. validHtmlStr($user->Username()),
-      (ZM_AUTH_TYPE == 'builtin'), 'id="logoutButton" data-toggle="modal" data-target="#modalLogout" data-backdrop="false"' ).PHP_EOL;
+      (ZM_AUTH_TYPE != 'remote'), 'id="logoutButton" data-toggle="modal" data-target="#modalLogout" data-backdrop="false"' ).PHP_EOL;
     $result .= '</li>'.PHP_EOL;
   }
   
