@@ -1,7 +1,7 @@
 function setButtonStates(element) {
-  var form = element.form;
+  const form = element.form;
   var checked = 0;
-  for ( var i=0; i < form.elements.length; i++ ) {
+  for ( var i=0, len = form.elements.length; i < len; i++ ) {
     if (
       form.elements[i].type == "checkbox" &&
       form.elements[i].name == "markMids[]"
@@ -19,28 +19,35 @@ function setButtonStates(element) {
     form.editBtn.disabled = false;
     form.deleteBtn.disabled = false;
     form.selectBtn.disabled = false;
-    if ( checked == 1 ) {
-      $j(form.cloneBtn).css('display', 'inline');
-    } else {
-      $j(form.cloneBtn).hide();
-    }
+    form.cloneBtn.disabled = false;
   } else {
-    $j(form.cloneBtn).hide();
     form.editBtn.disabled = true;
     form.deleteBtn.disabled = true;
     form.selectBtn.disabled = true;
+    form.cloneBtn.disabled = true;
   }
 }
 
+function scanNetwork(element) {
+  window.location.assign('?view=add_monitors');
+}
 function addMonitor(element) {
-  window.location.assign('?view=monitor');
+  if (user.Monitors == 'Create') {
+    window.location.assign('?view=monitor');
+  } else {
+    alert('Need create monitors privilege');
+  }
 }
 
 function cloneMonitor(element) {
+  if (user.Monitors != 'Create') {
+    alert('Need create monitors privilege');
+    return;
+  }
   var form = element.form;
-  var monitorId=-1;
+  var monitorId = -1;
   // get the value of the first checkbox
-  for ( var i = 0; i < form.elements.length; i++ ) {
+  for ( var i=0, len=form.elements.length; i < len; i++ ) {
     if (
       form.elements[i].type == "checkbox" &&
       form.elements[i].name == "markMids[]" &&
@@ -52,6 +59,8 @@ function cloneMonitor(element) {
   } // end foreach element
   if ( monitorId != -1 ) {
     window.location.assign('?view=monitor&dupId='+monitorId);
+  } else {
+    alert('Please select a monitor to clone');
   }
 }
 
@@ -78,8 +87,8 @@ function editMonitor( element ) {
 }
 
 function deleteMonitor( element ) {
-  if ( confirm( 'Warning, deleting a monitor also deletes all events and database entries associated with it.\nAre you sure you wish to delete?' ) ) {
-    var form = element.form;
+  if (confirm('Deleting a monitor only marks it as deleted.  Events will age out. If you want them to be immediately removed, please delete them first.\nAre you sure you wish to delete?')) {
+    const form = element.form;
     form.elements['action'].value = 'delete';
     form.submit();
   }
@@ -173,36 +182,31 @@ function manageFunctionModal(evt) {
 } // end function manageFunctionModal
 
 function initPage() {
-  setInterval(reloadWindow, consoleRefreshTimeout);
-  if ( showDonatePopup ) {
-    $j.getJSON(thisUrl + '?request=modal&modal=donate')
-        .done(function(data) {
-          insertModalHtml('donate', data.html);
-          $j('#donate').modal('show');
-          // Manage the Apply button
-          $j('#donateApplyBtn').click(function(evt) {
-            evt.preventDefault();
-            $j('#donateForm').submit();
-          });
-        })
-        .fail(logAjaxFail);
+  if (consoleRefreshTimeout > 0) {
+    setInterval(reloadWindow, consoleRefreshTimeout);
   }
 
-  // Makes table sortable
-  $j( function() {
-    $j( "#consoleTableBody" ).sortable({
-      handle: ".sort",
-      update: applySort,
-      axis: 'Y'} );
-    $j( "#consoleTableBody" ).disableSelection();
-  } );
-
   // Setup the thumbnail video animation
-  initThumbAnimation();
+  if (!isMobile()) initThumbAnimation();
 
   $j('.functionLnk').click(manageFunctionModal);
+
+  // Makes table sortable
+  $j('#consoleTableBody').sortable({
+    disabled: true,
+    update: applySort,
+    axis: 'Y'} );
 } // end function initPage
 
+function sortMonitors(button) {
+  if (button.classList.contains('btn-success')) {
+    $j( "#consoleTableBody" ).sortable('disable');
+  } else {
+    $j( "#consoleTableBody" ).sortable('enable');
+  }
+  button.classList.toggle('btn-success');
+}
+
 function applySort(event, ui) {
   var monitor_ids = $j(this).sortable('toArray');
   var data = {monitor_ids: monitor_ids, action: 'sort'};
@@ -211,4 +215,4 @@ function applySort(event, ui) {
       .fail(logAjaxFail);
 } // end function applySort(event,ui)
 
-$j(document).ready(initPage );
+$j(document).ready(initPage);
