@@ -1,3 +1,3 @@
-var eid = <?php echo validInt($_REQUEST['eid']) ?>;
+var eid = <?php echo validInt($_REQUEST['eid']) ?: "''"?>;
 var WEB_LIST_THUMBS = <?php echo ZM_WEB_LIST_THUMBS?'true':'false' ?>;
 var WEB_ANIMATE_THUMBS = <?php echo ZM_WEB_ANIMATE_THUMBS?'true':'false' ?>;
