@@ -905,7 +905,7 @@ function watchFullscreen() {
 
 function initGridStack(grid=null) {
   const opts = {
-    margin: '0 0px 0 0px',
+    margin: '0 1px 0 1px',
     cellHeight: '4px', //Required for correct use of objGridStack.resizeToContent
     sizeToContent: true, // default to make them all fit
     resizable: {handles: 'all'}, // do all sides
@@ -1095,11 +1095,14 @@ function checkEndMonitorsPlaced() {
 
     if (!movableMonitorData[id].stop) {
       //Monitor is still moving
-      const objWidth = document.getElementById('liveStream'+monitors[i].id).clientWidth;
-      if (objWidth == movableMonitorData[id].width && objWidth !=0 ) {
-        movableMonitorData[id].stop = true; //The size does not change, which means it’s already in its place!
-      } else {
-        movableMonitorData[id].width = objWidth;
+      const stream = document.getElementById('liveStream'+monitors[i].id);
+      if (stream) {
+        const objWidth = stream.clientWidth;
+        if (objWidth == movableMonitorData[id].width && objWidth !=0 ) {
+          movableMonitorData[id].stop = true; //The size does not change, which means it’s already in its place!
+        } else {
+          movableMonitorData[id].width = objWidth;
+        }
       }
     }
   }
@@ -1228,12 +1231,22 @@ document.onvisibilitychange = () => {
   }
 };
 
-// This is to stop the streams in a nicer way (no broken image) and hopefully faster.
+
+/*
 window.onbeforeunload = function(e) {
+  console.log('unload');
+  //event.preventDefault();
   for (let i = 0, length = monitorData.length; i < length; i++) {
     monitors[i].kill();
   }
-  return;
-  // Returning any value here, including undefined causes an undesired popup.
   var e = e || window.event;
+
+  // For IE and Firefox
+  if (e) {
+    e.returnValue = undefined;
+  }
+
+  // For Safari
+  return undefined;
 };
+*/
