@@ -117,7 +117,7 @@ if (isset($_REQUEST['zmMontageLayout'])) {
   $layout_id = validCardinal($_SESSION['zmMontageLayout']);
 }
 if (!$layout_id || !isset($layoutsById[$layout_id])) {
-  $layout_id = isset( $layoutsByName['Auto']) ? $layoutsByName['Auto']->Id() : 0;
+  $layout_id = $layoutsByName['Auto']->Id();
 }
 $layout = $layoutsById[$layout_id];
 $layout_is_preset = array_search($layout->Name(), $presetLayoutsNames) === false ? false : true;
@@ -370,6 +370,7 @@ foreach ($monitors as $monitor) {
     $monitor_options['state'] = !ZM_WEB_COMPACT_MONTAGE;
     $monitor_options['zones'] = $showZones;
     $monitor_options['mode'] = 'paused';
+    $monitor_options['connkey'] = $monitor->connKey();
     $browser_width = 1920;
     if (isset($_COOKIE['zmBrowserSizes'])) {
       $zmBrowserSizes =  jsonDecode($_COOKIE['zmBrowserSizes']);
@@ -391,6 +392,7 @@ foreach ($monitors as $monitor) {
       $monitor_options['scale'] = intval(100*(($browser_width/4)/$monitor->Width()));
       if ($monitor_options['scale'] > 100) $monitor_options['scale'] = 100;
       if ($monitor_options['scale'] < 10) $monitor_options['scale'] = 10;
+      $monitor->initial_scale($monitor_options['scale']);
     }
     echo $monitor->getStreamHTML($monitor_options);
   }
@@ -404,7 +406,7 @@ foreach ($monitors as $monitor) {
   <script src="/javascript/janus/janus.js"></script>
 <?php } ?>
 <?php if ($need_hls) { ?>
-  <script src="<?php echo cache_bust('js/hls-1.5.20/hls.min.js') ?>"></script>
+  <script src="<?php echo cache_bust('js/hls-1.6.13/hls.min.js') ?>"></script>
 <?php } ?>
   <script src="<?php echo cache_bust('js/MonitorStream.js') ?>"></script>
 
