@@ -18,7 +18,7 @@
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
 
-if (!canView('Stream')) {
+if (!canView('Stream') or !$user->canViewView('watch')) {
   $view = 'error';
   return;
 }
@@ -269,7 +269,7 @@ echo getNavBarHTML() ?>
     }
 ?>
 >
-          <span class="material-icons md-18">open_with</span>
+            <span class="material-icons md-18">open_with</span>
         </button>
       </div>
       <div class="form-check control-use-old-zoom-pan">
@@ -319,7 +319,7 @@ echo htmlSelect('changeRate', $maxfps_options, $options['maxfps'], ['class'=>'ch
               $players['rtsp2web_mse'] = 'RTSP2Web MSE';
               $players['rtsp2web_hls'] = 'RTSP2Web HLS';
               $players['janus'] = 'Janus';
-              $player = ''; # Auto
+              $player = validHtmlStr($monitor->DefaultPlayer());
               if (isset($_REQUEST['player']) and isset($players[$_REQUEST['player']])) {
                 $player = validHtmlStr($_REQUEST['player']);
               } else if (isset($_COOKIE['zmWatchPlayer']) and isset($players[$_COOKIE['zmWatchPlayer']])) {
@@ -395,6 +395,12 @@ echo htmlSelect('cyclePeriod', $cyclePeriodOptions, $period, array('id'=>'cycleP
     }
     echo '<li id="nav-item-cycle'.$m->Id().'" class="nav-item"><a id="nav-link'.$m->Id().'" class="nav-link'.( $m->Id() == $monitor->Id() ? ' active' : '' ).'" data-monIdx='.$dataMonIdx++.' href="#">'.$m->Name().'</a></li>';
   }
+  if ($monitorJanusUsed) {
+?>
+    <script src="<?php echo cache_bust('js/adapter.min.js') ?>"></script>
+    <script src="/javascript/janus/janus.js"></script>
+<?php
+  }
  ?>
           </ul>
         </nav>
